==> cmsmadesimple-1.8.2p0.tgz: cms/modules/ModuleManager/lang/ext/sk_SK.php <==
<?php
$lang['available_updates'] = 'Moduly dostupn&eacute; pre aktualiz&aacute;ciu';
$lang['all_modules_up_to_date'] = 'Nie s&uacute; žiadne nov&scaron;ie moduly v repozit&aacute;ry';
$lang['error_module_object'] = 'Chyba: nem&ocirc;že z&iacute;skať in&scaron;tanciu modulu %s';
$lang['error_nomatchingmodules'] = 'Chyba: nebola n&aacute;jden&aacute; zhoda v repozit&aacute;ri';
$lang['error_nomodules'] = 'Chyba: nenač&iacute;tan&yacute; zoznam použit&yacute;ch modulo';
$lang['upgrade_available'] = 'Nov&scaron;ia verzia dostupn&aacute; (%s), vy m&aacute;te (%s)';
$lang['newversions'] = 'Nain&scaron;talovan&eacute; moduly';
$lang['notice_depends'] = '%s depends on the following actions. Click &quot;Install&quot; to go ahead.';
$lang['install_submit'] = 'In&scaron;talovač';
$lang['depend_upgrade'] = 'Modul %s potrebuje aktualizovať na verziu %s.';
$lang['depend_install'] = 'Modul %s (verzia %s alebo niž&scaron;ia) potrebuje nain&scaron;talovať.';
$lang['depend_activate'] = 'Modul %s potrebuje byť aktitovan&yacute;.';
$lang['action_activated'] = 'Modul %s bol aktivovan&yacute;.';
$lang['action_installed'] = 'Modul %s nain&scaron;talovan&yacute; s nasleduj&uacute;cou spr&aacute;vou: %s';
$lang['action_upgraded'] = 'Modul %s bol aktualizovan&yacute;';
$lang['title_installation_complete'] = 'In&scaron;tal&aacute;cia kompletn&aacute;.';
$lang['install_with_deps'] = 'Overiť z&aacute;vistlosti a nain&scaron;talovať';
$lang['msg_nodependencies'] = 'Tento s&uacute;bor nem&aacute; žiadnu z&aacute;vislosť.';
$lang['error_upgrade'] = 'Aktualiz&aacute;cia modulu %s s chybou!';
$lang['error_skipping'] = 'Preskoči in&scaron;tal&aacute;ciu/aktualiz&aacute;ciu %s z d&ocirc;vodu chyby pri nastaveniach z&aacute;vislost&iacute;. Pros&iacute;m preč&iacute;tajte si niž&scaron;ie chybov&uacute; spr&aacute;vu a vysk&uacute;&scaron;ajte znovu.';
$lang['dependstxt'] = 'Z&aacute;vislosti';
$lang['use_at_your_own_risk'] = 'Použitie na vlastn&eacute; nepezpečenstvo';
$lang['compatibility_disclaimer'] = 'The modules displayed here are contributed by both the CMS Developers, and independant third parties.  We make no guarantees that the modules available here are functional, tested, or compatible with your system.  You are encouraged to read the information found in the help and about links for each module before attempting the installation.';
$lang['notice'] = 'Ozn&aacute;menie';
$lang['general_notice'] = 'The versions displayed here represent the latest XML files uploaded to your selected repository (usually the CMS %s).  They may or may not represent the latest available versions.  You may want to view the available file releases on the repository you have selected.  If you are using the default repository, you can do this by typing in the module name into the search box on the %s and clicking on the &quot;Files&quot; button.';
$lang['incompatible'] = 'Nekompatibiln&yacute;';
$lang['prompt_settings'] = 'Nastavenia';
$lang['prompt_otheroptions'] = 'Ostatn&eacute; voľby';
$lang['reset'] = 'Resetn&uacute;ť';
$lang['error_permissions'] = '<strong><em>Varovanie:</em></strong> Nedostatočn&eacute; pr&aacute;va pre adres&aacute;r modules. Pravdepodobne m&aacute;te zapnut&yacute; Safe m&oacute;d. Pros&iacute;m uistite sa, či m&aacute;te vypnut&yacute; Safe m&oacute;d, a že adres&aacute;r modules m&aacute; dostatočn&eacute; pr&aacute;va na zapisovanie.';
$lang['error_minimumrepository'] = 'Verzia repozit&aacute;ra nie je kompatibiln&aacute; s verziuo v&aacute;&scaron;ho spr&aacute;vcu modulov';
$lang['prompt_reseturl'] = 'Nastaviť adresu na prednestaven&uacute;';
$lang['prompt_resetcache'] = 'Nastaviť lok&aacute;lnu ke&scaron; pre d&aacute;ta z repozit&aacute;ra';
$lang['prompt_dl_chunksize'] = 'Veľkosť sťahovateľnej časti (Kb)';
$lang['text_dl_chunksize'] = 'Maxim&aacute;lne množstvo d&aacute;t pre stiahnutie v jednej časti (keď in&scaron;talujete modul)';
$lang['error_nofilesize'] = 'Veľkosť s&uacute;boru  nezn&aacute;my';
$lang['error_nofilename'] = 'N&aacute;zov s&uacute;boru nezn&aacute;my';
$lang['error_unsatisfiable_dependency'] = 'Nen&aacute;jden&eacute; vyžadovan&eacute; moduly &quot;%s&quot; (verzia %s alebo vy&scaron;&scaron;ia) v repozit&aacute;ri. Priamo vyžaduje %s; čo m&ocirc;že znamenať probl&eacute;my s touto verziou v repozit&aacute;ri. Pros&iacute;m kontaktujte v&yacute;voj&aacute;ra modulu.';
$lang['error_checksum'] = 'Chyba kontroln&eacute;ho s&uacute;čtu.  Vznik&aacute; v&auml;č&scaron;inou chybn&yacute;m nahrat&iacute;m s&uacute;boru do repozit&aacute;ra, alebo probl&eacute;mom pri sťahovan&iacute; na v&aacute;&scaron; server.';
$lang['cantdownload'] = 'Nie je možn&eacute; stiahovať';
$lang['download'] = 'Stiahn&uacute;ť a nian&scaron;talovať';
$lang['error_moduleinstallfailed'] = 'In&scaron;tal&aacute;cia modulu ne&uacute;spe&scaron;n&aacute;';
$lang['error_connectnomodules'] = 'Aj keď pripojenie k repozit&aacute;ru prebehlo &uacute;spe&scaron;ne, vypad&aacute; to tak, že repozit&aacute;r  aktu&aacute;lne nezobrazuje žiadne data.';
$lang['submit'] = 'Odoslať';
$lang['text_repository_url'] = 'Adresa vo formul&aacute;ri m&ocirc;že byť http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'Adresa zdroja repozit&aacute;ra modulov';
$lang['title_installation'] = 'In&scaron;tal&aacute;cia';
$lang['availmodules'] = 'Dostupn&eacute; moduly';
$lang['preferences'] = 'Nastavenia';
$lang['preferencessaved'] = 'Nastavenia uložen&eacute;';
$lang['repositorycount'] = 'Moduly n&aacute;jden&eacute; v repozit&aacute;ry';
$lang['instcount'] = 'Nain&scaron;talovan&eacute; moduly';
$lang['availablemodules'] = 'S&uacute;časn&yacute; stav modulov dostupn&eacute; v repozit&aacute;ri';
$lang['time_warning'] = 'The installation list has more than one or two modules. Be aware that the install could take a few minutes. Please be patient!';
$lang['helptxt'] = 'Pomocn&iacute;k k modulu';
$lang['abouttxt'] = 'O module';
$lang['xmltext'] = 'XML s&uacute;bor';
$lang['nametext'] = 'N&aacute;zov modulu';
$lang['mod_name_ver'] = '%s verzia %s';
$lang['unknown'] = 'Nezn&aacute;me';
$lang['vertext'] = 'Verzia';
$lang['sizetext'] = 'Veľkosť (kilobajty)';
$lang['statustext'] = 'Stav/Akcia';
$lang['uptodate'] = 'Nain&scaron;talovan&yacute;';
$lang['install'] = 'in&scaron;talovať';
$lang['newerversion'] = 'Je nain&scaron;talovan&aacute; nov&scaron;ia verzia';
$lang['onlynewesttext'] = 'Zobraziť iba najnov&scaron;iu verziu';
$lang['upgrade'] = 'Aktualiz&aacute;cia';
$lang['error_nosoapconnect'] = 'Nem&ocirc;žem sa pripojiť k serveru SOAP';
$lang['error_soaperror'] = 'Problem u SOAP';
$lang['soaperror'] = 'SOAP chyba: %s';
$lang['error_norepositoryurl'] = 'Addresa pre repozit&aacute;r modul nebol zadan&yacute;';
$lang['friendlyname'] = 'Spr&aacute;va modulov';
$lang['postinstall'] = 'Modul Spr&aacute;va modulov vol &uacute;spe&scaron;ne nain&scaron;talovan&yacute;';
$lang['postuninstall'] = 'Spr&aacute;vca modulov odin&scaron;talovany.  Už nebudete m&ocirc;cť  in&scaron;talovať moduly z repozit&aacute;ra, av&scaron;ak nain&scaron;talovan&eacute; moduly na va&scaron;om serveri ost&aacute;vaju bežať.';
$lang['really_uninstall'] = 'Ste si ist&yacute;, že chcete odin&scaron;talovať tento modul? Pr&iacute;dete o p&aacute;r pekn&yacute;ch funkci&iacute;.';
$lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
$lang['installed'] = 'Modul verzia %s nain&scaron;talovan&yacute;.';
$lang['upgraded'] = 'Modul aktualizovan&yacute; na verziu %s.';
$lang['moddescription'] = 'A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.';
$lang['back_to_module_manager'] = '&laquo; n&aacute;vrat do spr&aacute;vcu modulov';
$lang['error'] = 'Chyba!';
$lang['admindescription'] = 'N&aacute;stroj pre vyhľad&aacute;vanie a in&scaron;talovanie modulov cez vzdialen&yacute; server.';
$lang['accessdenied'] = 'Pr&iacute;stup zamietnut&yacute;. Pros&iacute;m skontrolujte svoje pr&aacute;va.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Site Admin&#039; --> &#039;Global Settings&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['qca'] = 'P0-1608926040-1271144175783';
$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
$lang['chartbeat2'] = '87v0u4nbwegh3lki';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p3.tgz: cms/modules/ModuleManager/lang/ext/sk_SK.php <==
<?php
$lang['error_searchterm'] = 'Pros&iacute;m zadajte vyhľad&aacute;vaci dotaz';
$lang['search_noresults'] = 'Neboli n&aacute;jdene žiadne položky';
$lang['advancedsearch_help'] = 'Konrektizujte hľadan&eacute; slova pomocou +,- (vr&aacute;tane, okrem), napr&iacute;klad fr&aacute;zu s &uacute;vodzovkami &quot;+červen&eacute; -jablko+&quot;nejak&yacute; text&quot;';
$lang['search_results'] = 'V&yacute;sledky vyhľad&aacute;vania';
$lang['prompt_advancedsearch'] = 'Roz&scaron;&iacute;ren&eacute; vyhľad&aacute;vanie';
$lang['search_input'] = 'Vyhľad&aacute;vanie';
$lang['searchterm'] = 'Vyhľad&aacute;vac&iacute; dotaz';
$lang['search'] = 'Vyhľad&aacute;vanie';
$lang['available_updates'] = 'Moduly dostupn&eacute; pre aktualiz&aacute;ciu';
$lang['all_modules_up_to_date'] = 'Nie s&uacute; žiadne nov&scaron;ie moduly v repozit&aacute;ry';
$lang['error_module_object'] = 'Chyba: nem&ocirc;že z&iacute;skať in&scaron;tanciu modulu %s';
$lang['error_nomatchingmodules'] = 'Chyba: nebola n&aacute;jden&aacute; zhoda v repozit&aacute;ri';
$lang['error_nomodules'] = 'Chyba: nenač&iacute;tan&yacute; zoznam použit&yacute;ch modulo';
$lang['upgrade_available'] = 'Nov&scaron;ia verzia dostupn&aacute; (%s), vy m&aacute;te (%s)';
$lang['newversions'] = 'Nain&scaron;talovan&eacute; moduly';
$lang['notice_depends'] = '%s depends on the following actions. Click &quot;Install&quot; to go ahead.';
$lang['install_submit'] = 'In&scaron;talovať';
$lang['depend_upgrade'] = 'Modul %s potrebuje aktualizovať na verziu %s.';
$lang['depend_install'] = 'Modul %s (verzia %s alebo niž&scaron;ia) potrebuje nain&scaron;talovať.';
$lang['depend_activate'] = 'Modul %s potrebuje byť aktitovan&yacute;.';
$lang['action_activated'] = 'Modul %s bol aktivovan&yacute;.';
$lang['action_installed'] = 'Modul %s nain&scaron;talovan&yacute; s nasleduj&uacute;cou spr&aacute;vou: %s';
$lang['action_upgraded'] = 'Modul %s bol aktualizovan&yacute;';
$lang['title_installation_complete'] = 'In&scaron;tal&aacute;cia kompletn&aacute;.';
$lang['install_with_deps'] = 'Overiť z&aacute;vistlosti a nain&scaron;talovať';
$lang['msg_nodependencies'] = 'Tento s&uacute;bor nem&aacute; žiadnu z&aacute;vislosť.';
$lang['error_upgrade'] = 'Aktualiz&aacute;cia modulu %s s chybou!';
$lang['error_skipping'] = 'Preskoči in&scaron;tal&aacute;ciu/aktualiz&aacute;ciu %s z d&ocirc;vodu chyby pri nastaveniach z&aacute;vislost&iacute;. Pros&iacute;m preč&iacute;tajte si niž&scaron;ie chybov&uacute; spr&aacute;vu a vysk&uacute;&scaron;ajte znovu.';
$lang['dependstxt'] = 'Z&aacute;vislosti';
$lang['use_at_your_own_risk'] = 'Použitie na vlastn&eacute; nepezpečenstvo';
$lang['compatibility_disclaimer'] = 'The modules displayed here are contributed by both the CMS Developers, and independant third parties.  We make no guarantees that the modules available here are functional, tested, or compatible with your system.  You are encouraged to read the information found in the help and about links for each module before attempting the installation.';
$lang['notice'] = 'Ozn&aacute;menie';
$lang['general_notice'] = 'The versions displayed here represent the latest XML files uploaded to your selected repository (usually the CMS %s).  They may or may not represent the latest available versions.  You may want to view the available file releases on the repository you have selected.  If you are using the default repository, you can do this by typing in the module name into the search box on the %s and clicking on the &quot;Files&quot; button.';
$lang['incompatible'] = 'Nekompatibiln&yacute;';
$lang['prompt_settings'] = 'Nastavenia';
$lang['prompt_otheroptions'] = 'Ostatn&eacute; voľby';
$lang['reset'] = 'Resetn&uacute;ť';
$lang['error_permissions'] = '<strong><em>Varovanie:</em></strong> Nedostatočn&eacute; pr&aacute;va pre adres&aacute;r modules. Pravdepodobne m&aacute;te zapnut&yacute; Safe m&oacute;d. Pros&iacute;m uistite sa, či m&aacute;te vypnut&yacute; Safe m&oacute;d, a že adres&aacute;r modules m&aacute; dostatočn&eacute; pr&aacute;va na zapisovanie.';
$lang['error_minimumrepository'] = 'Verzia repozit&aacute;ra nie je kompatibiln&aacute; s verziuo v&aacute;&scaron;ho spr&aacute;vcu modulov';
$lang['prompt_reseturl'] = 'Nastaviť adresu na prednestaven&uacute;';
$lang['prompt_resetcache'] = 'Nastaviť lok&aacute;lnu ke&scaron; pre d&aacute;ta z repozit&aacute;ra';
$lang['prompt_dl_chunksize'] = 'Veľkosť sťahovateľnej časti (Kb)';
$lang['text_dl_chunksize'] = 'Maxim&aacute;lne množstvo d&aacute;t pre stiahnutie v jednej časti (keď in&scaron;talujete modul)';
$lang['error_nofilesize'] = 'Veľkosť s&uacute;boru  nezn&aacute;my';
$lang['error_nofilename'] = 'N&aacute;zov s&uacute;boru nezn&aacute;my';
$lang['error_unsatisfiable_dependency'] = 'Nen&aacute;jden&eacute; vyžadovan&eacute; moduly &quot;%s&quot; (verzia %s alebo vy&scaron;&scaron;ia) v repozit&aacute;ri. Priamo vyžaduje %s; čo m&ocirc;že znamenať probl&eacute;my s touto verziou v repozit&aacute;ri. Pros&iacute;m kontaktujte v&yacute;voj&aacute;ra modulu.';
$lang['error_checksum'] = 'Chyba kontroln&eacute;ho s&uacute;čtu.  Vznik&aacute; v&auml;č&scaron;inou chybn&yacute;m nahrat&iacute;m s&uacute;boru do repozit&aacute;ra, alebo probl&eacute;mom pri sťahovan&iacute; na v&aacute;&scaron; server.';
$lang['cantdownload'] = 'Nie je možn&eacute; stiahovať';
$lang['download'] = 'Stiahn&uacute;ť a nian&scaron;talovať';
$lang['error_moduleinstallfailed'] = 'In&scaron;tal&aacute;cia modulu ne&uacute;spe&scaron;n&aacute;';
$lang['error_connectnomodules'] = 'Aj keď pripojenie k repozit&aacute;ru prebehlo &uacute;spe&scaron;ne, vypad&aacute; to tak, že repozit&aacute;r  aktu&aacute;lne nezobrazuje žiadne data.';
$lang['submit'] = 'Odoslať';
$lang['text_repository_url'] = 'Adresa vo formul&aacute;ri m&ocirc;že byť http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'Adresa zdroja repozit&aacute;ra modulov';
$lang['title_installation'] = 'In&scaron;tal&aacute;cia';
$lang['availmodules'] = 'Dostupn&eacute; moduly';
$lang['preferences'] = 'Nastavenia';
$lang['preferencessaved'] = 'Nastavenia uložen&eacute;';
$lang['repositorycount'] = 'Moduly n&aacute;jden&eacute; v repozit&aacute;ry';
$lang['instcount'] = 'Nain&scaron;talovan&eacute; moduly';
$lang['availablemodules'] = 'S&uacute;časn&yacute; stav modulov dostupn&eacute; v repozit&aacute;ri';
$lang['time_warning'] = 'Zoznam modul pre in&scaron;tal&aacute;ciu obsahuje viac ako1-2 moduly. Budte opatrn&yacute;, in&scaron;tal&aacute;cia m&ocirc;že trvať  niekoľko min&uacute;t';
$lang['helptxt'] = 'Pomocn&iacute;k k modulu';
$lang['abouttxt'] = 'O module';
$lang['xmltext'] = 'XML s&uacute;bor';
$lang['nametext'] = 'N&aacute;zov modulu';
$lang['mod_name_ver'] = '%s verzia %s';
$lang['unknown'] = 'Nezn&aacute;me';
$lang['vertext'] = 'Verzia';
$lang['sizetext'] = 'Veľkosť (kilobajty)';
$lang['statustext'] = 'Stav/Akcia';
$lang['uptodate'] = 'Nain&scaron;talovan&yacute;';
$lang['install'] = 'in&scaron;talovať';
$lang['newerversion'] = 'Je nain&scaron;talovan&aacute; nov&scaron;ia verzia';
$lang['onlynewesttext'] = 'Zobraziť iba najnov&scaron;iu verziu';
$lang['upgrade'] = 'Aktualiz&aacute;cia';
$lang['error_nosoapconnect'] = 'Nem&ocirc;žem sa pripojiť k serveru SOAP';
$lang['error_soaperror'] = 'Problem u SOAP';
$lang['soaperror'] = 'SOAP chyba: %s';
$lang['error_norepositoryurl'] = 'Addresa pre repozit&aacute;r modul nebol zadan&yacute;';
$lang['friendlyname'] = 'Spr&aacute;va modulov';
$lang['postinstall'] = 'Modul Spr&aacute;va modulov vol &uacute;spe&scaron;ne nain&scaron;talovan&yacute;';
$lang['postuninstall'] = 'Spr&aacute;vca modulov odin&scaron;talovany.  Už nebudete m&ocirc;cť  in&scaron;talovať moduly z repozit&aacute;ra, av&scaron;ak nain&scaron;talovan&eacute; moduly na va&scaron;om serveri ost&aacute;vaju bežať.';
$lang['really_uninstall'] = 'Ste si ist&yacute;, že chcete odin&scaron;talovať tento modul? Pr&iacute;dete o p&aacute;r pekn&yacute;ch funkci&iacute;.';
$lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
$lang['installed'] = 'Modul verzia %s nain&scaron;talovan&yacute;.';
$lang['upgraded'] = 'Modul aktualizovan&yacute; na verziu %s.';
$lang['moddescription'] = 'Klient pre repozit&aacute;r modulov, umožňuje n&aacute;hľad a in&scaron;tal&aacute;ciu modulov zo serverou bez použitia FTP alebo rozbaľovania, Moduly vo form&aacute;te XML s&uacute; &scaron;tahovan&eacute; cez protokol SOAP, verifikovan&eacute; a automatick&yacute; nahr&aacute;van&eacute;.';
$lang['back_to_module_manager'] = '&laquo; n&aacute;vrat do spr&aacute;vcu modulov';
$lang['error'] = 'Chyba!';
$lang['admindescription'] = 'N&aacute;stroj pre vyhľad&aacute;vanie a in&scaron;talovanie modulov cez vzdialen&yacute; server.';
$lang['accessdenied'] = 'Pr&iacute;stup zamietnut&yacute;. Pros&iacute;m skontrolujte svoje pr&aacute;va.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Site Admin&#039; --> &#039;Global Settings&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utmc'] = '156861353';
$lang['qca'] = 'P0-1608926040-1271144175783';
$lang['utma'] = '156861353.786385904.1271157997.1297167781.1297170856.166';
$lang['utmz'] = '156861353.1297170856.166.151.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
$lang['utmb'] = '156861353.1.10.1297170856';
?>
